@@ -21,9 +21,8 @@ class Run:
         self.other_rewards = episode_data.other_rewards
         self.attacks = episode_data.attacks
         self.attacks_id = None
-        self.episode_data = episode_data
         self.reset_attacks_id()
 
     def reset_attacks_id(self):
         self.attacks_id = [None if attack is None or len(attack.impact_on_objects()['force_line']['disconnections']['powerlines']) == 0 else
-                           attack.impact_on_objects()['force_line']['disconnections']['powerlines'][0] for attack in self.attacks]
\ No newline at end of file
+                           float(attack.impact_on_objects()['force_line']['disconnections']['powerlines'][0]) for attack in self.attacks]
\ No newline at end of file
